@@ -1,4 +1,4 @@
-# $Id: /local/CPAN/Handel/lib/Handel/Cart.pm 1043 2007-06-24T15:35:46.298350Z claco  $
+# $Id: /local/CPAN/Handel/lib/Handel/Cart.pm 1167 2008-01-10T04:20:50.380568Z claco  $
 package Handel::Cart;
 use strict;
 use warnings;
@@ -184,8 +184,15 @@ sub restore {
         $self->clear;
 
         my $first = $carts[0];
-        $self->name($first->name);
-        $self->description($first->description);
+
+        ## this is hacky..needs to be more generic
+        ## since neither could have them, or rename them
+        if ($self->can('name') && $first->can('name')) {
+            $self->name($first->name);
+        };
+        if ($self->can('description') && $first->can('description')) {
+            $self->description($first->description);
+        };
 
         foreach my $cart (@carts) {
             my @items = $cart->items->all;
@@ -197,8 +204,10 @@ sub restore {
         foreach my $cart (@carts) {
             my @items = $cart->items->all;
             foreach my $item (@items) {
-                if (my $exists = $self->items({sku => $item->sku})->first){
-                    $exists->quantity($item->quantity + $exists->quantity);
+                if (my $exists = $self->items({sku => $item->sku})->first) {
+                    $exists->update({
+                        quantity => $item->quantity + $exists->quantity
+                    });
                 } else {
                     $self->add($item);
                 };
